import { usePageTranslationsQuery } from "@saleor/graphql";
import usePaginator from "@saleor/hooks/usePaginator";
import TranslationsEntitiesList from "@saleor/translations/components/TranslationsEntitiesList";
import {
  languageEntityUrl,
  TranslatableEntities
} from "@saleor/translations/urls";
import { mapEdgesToItems } from "@saleor/utils/maps";
import React from "react";

import { TranslationsEntityListProps } from "./types";
import { sumCompleted } from "./utils";

const TranslationsPageList: React.FC<TranslationsEntityListProps> = ({
  params,
  variables
}) => {
  const paginate = usePaginator();

  const { data, loading } = usePageTranslationsQuery({
    displayLoader: true,
    variables
  });

  const { loadNextPage, loadPreviousPage, pageInfo } = paginate(
    data?.translations?.pageInfo,
    variables,
    params
  );

  return (
    <TranslationsEntitiesList
      disabled={loading}
      entities={mapEdgesToItems(data?.translations)?.map(
        node =>
          node.__typename === "PageTranslatableContent" && {
            completion: {
              current: sumCompleted([
                node.translation?.content,
                node.translation?.seoDescription,
                node.translation?.seoTitle,
                node.translation?.title
              ]),
              max: 4
            },
            id: node?.page.id,
            name: node?.page.title
          }
      )}
      getRowHref={id =>
        languageEntityUrl(variables.language, TranslatableEntities.pages, id)
      }
      onNextPage={loadNextPage}
      onPreviousPage={loadPreviousPage}
      pageInfo={pageInfo}
    />
  );
};

export default TranslationsPageList;
